==> nextcloud-app-spreed-1%3A9.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/sq.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
    "Guest" : "I ftuar",
    "Open settings" : "Hap rregullimet",
    "Conversations" : "Bisedat",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratet e Bashkuara Arabe",
    "Afghanistan" : "Afganistani",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Shqipëria",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktiku",
    "Argentina" : "Argjentina",
    "American Samoa" : "Samoa Amerikane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ishujt Oland",
    "Azerbaijan" : "Azerbajxhani",
    "Bosnia and Herzegovina" : "Bosnja and Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgjika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bullgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Bermuda" : "Bermuda",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butani",
    "Botswana" : "Botsvana",
    "Belarus" : "Bjellorusi",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Congo" : "Kongo",
    "Switzerland" : "Zvicër",
    "Côte d'Ivoire" : "Bregu i Fildishtë",
    "Chile" : "Kili",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Kolumbi",
    "Cuba" : "Kubë",
    "Cabo Verde" : "Kepi i Gjelbër",
    "Cyprus" : "Qipro",
    "Germany" : "Gjermani",
    "Denmark" : "Danimarkë",
    "Algeria" : "Algjeria",
    "Ecuador" : "Ekuadori",
    "Estonia" : "Estonia",
    "Egypt" : "Egjipt",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanja",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlanda",
    "Fiji" : "Fixhi",
    "France" : "Franca",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Mbretëria e Bashkuar e Britanisë së Madhe dhe Irlandës Veriore",
    "Georgia" : "Gjeorgji",
    "Ghana" : "Gana",
    "Gibraltar" : "Gjibraltar",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Greece" : "Greqi",
    "Guatemala" : "Guatemala",
    "Honduras" : "Honduras",
    "Croatia" : "Kroaci",
    "Haiti" : "Haiti",
    "Hungary" : "Hungari",
    "Indonesia" : "Indonezia",
    "Ireland" : "Irlanda",
    "Israel" : "Izraeli",
    "India" : "India",
    "Iraq" : "Irak",
    "Iceland" : "Islanda",
    "Italy" : "Itali",
    "Jamaica" : "Xhamaika",
    "Jordan" : "Jordani",
    "Japan" : "Japoni",
    "Kenya" : "Kenia",
    "Cambodia" : "Kamboxhia",
    "Kiribati" : "Kiribati",
    "Kuwait" : "Kuvajti",
    "Kazakhstan" : "Kazakistani",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luksemburgu",
    "Libya" : "Libia",
    "Morocco" : "Maroku",
    "Montenegro" : "Mali i Zi",
    "Mali" : "Mali",
    "Mongolia" : "Mongolia",
    "Malta" : "Malta",
    "Mexico" : "Meksikë",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Hollandë",
    "Norway" : "Norvegji",
    "Nepal" : "Nepal",
    "New Zealand" : "Zelanda e Re",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Pakistan" : "Pakistan",
    "Poland" : "Poloni",
    "Puerto Rico" : "Puerto Riko",
    "Portugal" : "Portugali",
    "Paraguay" : "Paraguaj",
    "Qatar" : "Qatar",
    "Romania" : "Rumania",
    "Serbia" : "Serbi",
    "Russian Federation" : "Federata Ruse",
    "Saudi Arabia" : "Arabia Saudite",
    "Sudan" : "Sudan",
    "Sweden" : "Suedi",
    "Singapore" : "Singapori",
    "Slovenia" : "Sllovenia",
    "Slovakia" : "Sllovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegali",
    "Somalia" : "Somalia",
    "Syrian Arab Republic" : "Republika Arabe e Sirisë",
    "Chad" : "Çad",
    "Togo" : "Togo",
    "Thailand" : "Tajlanda",
    "Tajikistan" : "Taxhikistan",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizia",
    "Tonga" : "Tonga",
    "Turkey" : "Turqi",
    "Ukraine" : "Ukrainë",
    "Uganda" : "Uganda",
    "United States of America" : "Shtetet e Bashkuara të Amerikës",
    "Uruguay" : "Uruguaj",
    "Zambia" : "Zambia",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Leave call" : "Lini një thirrje",
    "Limit to groups" : "Kufizo grupet",
    "Everyone" : "Kushdo",
    "Save changes" : "Ruaj ndryshimet",
    "Saved!" : "I/E ruajtur!",
    "None" : "Asnjë",
    "User" : "Përdorues",
    "Disabled" : "I çaktivizuar",
    "Users" : "Përdoruesit",
    "Name" : "Emri",
    "General settings" : "Opsjonet e Pergjithshme",
    "Language" : "Gjuha",
    "Country" : "Vend",
    "Status" : "Status",
    "Created at" : "U krijua në",
    "Pending" : "Në Pritje të Konfirmimit",
    "Error" : "Error",
    "Blocked" : "I bllokuar",
    "Saved" : "U ruajt",
    "TURN server protocols" : "Protokollet e serverit TURN",
    "UDP and TCP" : "UDP dhe TCP",
    "UDP only" : "Vetëm UDP",
    "TCP only" : "Vetëm TCP",
    "Copy link" : "Kopjo linkun",
    "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
    "Show your screen" : "Shfaq ekranin tënd",
    "Stop screensharing" : "Ndalo ndarjen e ekranit",
    "Dismiss" : "Hiq",
    "Mute audio" : "Mute audio",
    "Disable video" : "Çaktivizo video",
    "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
    "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
    "You" : "Ju",
    "Favorite" : "I/E Preferuar",
    "Leave conversation" : "Largohuni nga biseda",
    "Delete conversation" : "Fshijeni bisedën",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Shtoje tek të parapëlqyerat",
    "Loading" : "Duke ngarkuar",
    "Groups" : "Grupet",
    "Circles" : "Rrethet",
    "Password protect" : "Mbroje me fjalëkalim",
    "Back" : "Prapa",
    "Close" : "Mbylleni",
    "Conversation name" : "Emri i bisedës",
    "Reply" : "Përgjigju",
    "Today" : "Sot",
    "Yesterday" : "Dje",
    "Send message" : "Dërgo mesazh",
    "guest" : "vizitor",
    "No results" : "Asnjë rezultat",
    "Add users or groups" : "Add users or groups",
    "Settings" : "Rregullimet",
    "Edit" : "Përpuno",
    "Rename conversation" : "Riemërtojeni bisedën",
    "Share link" : "Shpërndaj ndërlidhjen",
    "Password protection" : "Password protection",
    "Enter a password" : "Fusni një fjalëkalim",
    "Grid view" : "Pamje galeri",
    "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
    "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
    "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
    "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
    "Error while accessing microphone & camera" : "gabim ",
    "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
    "Password" : "Fjalëkalim",
    "TURN server" : "Serveri TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
    "Android app" : "Aplikacion Android",
    "iOS app" : "Aplikacion iOS",
    "Copy" : "Kopjo",
    "Copied!" : "U kopjua!",
    "Not supported!" : "Nuk mbështetet!",
    "Press ⌘-C to copy." : "Shtyni ⌘-C që të kopjoni.",
    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar",
    "Password required" : "Kërkohet fjalëkalimi",
    "Cancel" : "Anulo",
    "Submit" : "Dërgo",
    "Guests" : "Të ftuarit",
    "Change password" : "Ndryshoni fjalëkalimin",
    "Set password" : "Vendos fjalëkalimin",
    "Rename" : "Riemëroj",
    "Send" : "Dërgo",
    "Share" : "Shpërndaje",
    "Error while sharing" : "Gabim gjatë ndarjes",
    "No other people in this call" : "Jo njerëz të tjerë në këtë thirrje",
    "Waiting for {participantName} to join the call …" : "Duke pritur për {participantName} që ti bashkohet telefonatës ...",
    "WebRTC is not supported in your browser :-/" : "WebRTC nuk suportohet nga shfletuesi juaj :-/",
    "Waiting for camera and microphone permissions" : "Duke pritur për autorizimin e kameras dhe mikrofonit ",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Ju lutemi, ti jepni akses browser-it tuaj për të përdorur kameran dhe mikrofonin në mënyrë që të përdorni këtë app.",
    "Share screen" : "Ndaje ekranin",
    "Screensharing is not supported by your browser." : "Ndarja e erkaneve nuk është e mbështetur nga shfletuesi juaj ",
    "Favorited" : "U kalua e parapëlqyer",
    "Your screen" : "Ekrani juaj",
    "{participantName}'s screen" : "Ekrani i {participantName}",
    "Guest's screen" : "Ekrani i të ftuarit",
    "Contacts" : "Kontaktet"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A10.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/sq.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
    "Guest" : "I ftuar",
    "Open settings" : "Hap rregullimet",
    "Conversations" : "Bisedat",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratet e Bashkuara Arabe",
    "Afghanistan" : "Afganistani",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Shqipëria",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktiku",
    "Argentina" : "Argjentina",
    "American Samoa" : "Samoa Amerikane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ishujt Oland",
    "Azerbaijan" : "Azerbajxhani",
    "Bosnia and Herzegovina" : "Bosnja and Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgjika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bullgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Bermuda" : "Bermuda",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butani",
    "Botswana" : "Botsvana",
    "Belarus" : "Bjellorusi",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Congo" : "Kongo",
    "Switzerland" : "Zvicër",
    "Côte d'Ivoire" : "Bregu i Fildishtë",
    "Chile" : "Kili",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Kolumbi",
    "Cuba" : "Kubë",
    "Cabo Verde" : "Kepi i Gjelbër",
    "Cyprus" : "Qipro",
    "Germany" : "Gjermani",
    "Denmark" : "Danimarkë",
    "Algeria" : "Algjeria",
    "Ecuador" : "Ekuadori",
    "Estonia" : "Estonia",
    "Egypt" : "Egjipt",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanja",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlanda",
    "Fiji" : "Fixhi",
    "France" : "Franca",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Mbretëria e Bashkuar e Britanisë së Madhe dhe Irlandës Veriore",
    "Georgia" : "Gjeorgji",
    "Ghana" : "Gana",
    "Gibraltar" : "Gjibraltar",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Greece" : "Greqi",
    "Guatemala" : "Guatemala",
    "Honduras" : "Honduras",
    "Croatia" : "Kroaci",
    "Haiti" : "Haiti",
    "Hungary" : "Hungari",
    "Indonesia" : "Indonezia",
    "Ireland" : "Irlanda",
    "Israel" : "Izraeli",
    "India" : "India",
    "Iraq" : "Irak",
    "Iceland" : "Islanda",
    "Italy" : "Itali",
    "Jamaica" : "Xhamaika",
    "Jordan" : "Jordani",
    "Japan" : "Japoni",
    "Kenya" : "Kenia",
    "Cambodia" : "Kamboxhia",
    "Kiribati" : "Kiribati",
    "Kuwait" : "Kuvajti",
    "Kazakhstan" : "Kazakistani",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luksemburgu",
    "Libya" : "Libia",
    "Morocco" : "Maroku",
    "Montenegro" : "Mali i Zi",
    "Mali" : "Mali",
    "Mongolia" : "Mongolia",
    "Malta" : "Malta",
    "Mexico" : "Meksikë",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Hollandë",
    "Norway" : "Norvegji",
    "Nepal" : "Nepal",
    "New Zealand" : "Zelanda e Re",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Pakistan" : "Pakistan",
    "Poland" : "Poloni",
    "Puerto Rico" : "Puerto Riko",
    "Portugal" : "Portugali",
    "Paraguay" : "Paraguaj",
    "Qatar" : "Qatar",
    "Romania" : "Rumania",
    "Serbia" : "Serbi",
    "Russian Federation" : "Federata Ruse",
    "Saudi Arabia" : "Arabia Saudite",
    "Sudan" : "Sudan",
    "Sweden" : "Suedi",
    "Singapore" : "Singapori",
    "Slovenia" : "Sllovenia",
    "Slovakia" : "Sllovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegali",
    "Somalia" : "Somalia",
    "Syrian Arab Republic" : "Republika Arabe e Sirisë",
    "Chad" : "Çad",
    "Togo" : "Togo",
    "Thailand" : "Tajlanda",
    "Tajikistan" : "Taxhikistan",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizia",
    "Tonga" : "Tonga",
    "Turkey" : "Turqi",
    "Ukraine" : "Ukrainë",
    "Uganda" : "Uganda",
    "United States of America" : "Shtetet e Bashkuara të Amerikës",
    "Uruguay" : "Uruguaj",
    "Zambia" : "Zambia",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Leave call" : "Lini një thirrje",
    "Limit to groups" : "Kufizo grupet",
    "Everyone" : "Kushdo",
    "Save changes" : "Ruaj ndryshimet",
    "Saved!" : "I/E ruajtur!",
    "None" : "Asnjë",
    "User" : "Përdorues",
    "Disabled" : "I çaktivizuar",
    "Users" : "Përdoruesit",
    "Name" : "Emri",
    "General settings" : "Opsjonet e Pergjithshme",
    "Language" : "Gjuha",
    "Country" : "Vend",
    "Status" : "Status",
    "Created at" : "U krijua në",
    "Pending" : "Në Pritje të Konfirmimit",
    "Error" : "Error",
    "Blocked" : "I bllokuar",
    "Saved" : "U ruajt",
    "TURN server protocols" : "Protokollet e serverit TURN",
    "UDP and TCP" : "UDP dhe TCP",
    "UDP only" : "Vetëm UDP",
    "TCP only" : "Vetëm TCP",
    "Copy link" : "Kopjo linkun",
    "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
    "Show your screen" : "Shfaq ekranin tënd",
    "Stop screensharing" : "Ndalo ndarjen e ekranit",
    "Dismiss" : "Hiq",
    "Mute audio" : "Mute audio",
    "Disable video" : "Çaktivizo video",
    "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
    "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
    "You" : "Ju",
    "Favorite" : "I/E Preferuar",
    "Leave conversation" : "Largohuni nga biseda",
    "Delete conversation" : "Fshijeni bisedën",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Shtoje tek të parapëlqyerat",
    "Loading" : "Duke ngarkuar",
    "Groups" : "Grupet",
    "Circles" : "Rrethet",
    "Settings" : "Rregullimet",
    "Password protect" : "Mbroje me fjalëkalim",
    "Back" : "Prapa",
    "Close" : "Mbylleni",
    "Conversation name" : "Emri i bisedës",
    "Camera" : "Kamera",
    "Reply" : "Përgjigju",
    "Remove" : "Hiq",
    "Today" : "Sot",
    "Yesterday" : "Dje",
    "Send message" : "Dërgo mesazh",
    "Enabled" : "I aktivizuar",
    "Save" : "Ruaj",
    "Password" : "Fjalëkalim",
    "API token" : "Çelës identifikues i API-t ",
    "Login" : "Hyrje",
    "Nickname" : "Nofkë",
    "Client ID" : "ID klienti",
    "guest" : "vizitor",
    "No results" : "Asnjë rezultat",
    "Add users or groups" : "Add users or groups",
    "Edit" : "Përpuno",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Search" : "Kërko",
    "Rename conversation" : "Riemërtojeni bisedën",
    "Share link" : "Shpërndaj ndërlidhjen",
    "Password protection" : "Password protection",
    "Enter a password" : "Fusni një fjalëkalim",
    "Grid view" : "Pamje galeri",
    "Send" : "Dërgo",
    "Start a conversation" : "Filloni një bisedë",
    "Default" : "E paracaktuar",
    "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
    "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
    "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
    "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
    "Error while accessing microphone & camera" : "gabim ",
    "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
    "TURN server" : "Serveri TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
    "Android app" : "Aplikacion Android",
    "iOS app" : "Aplikacion iOS",
    "No other people in this call" : "Jo njerëz të tjerë në këtë thirrje",
    "Your screen" : "Ekrani juaj",
    "Contacts" : "Kontaktet",
    "Guests" : "Të ftuarit",
    "Password required" : "Kërkohet fjalëkalimi",
    "Cancel" : "Anulo",
    "Submit" : "Dërgo"
},
"nplurals=2; plural=(n != 1);");
